==> touhoulittlemaid-fabric-1.21.1-0.0.6-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/datagen/tag/EntityTypeGenerator.java <==
package com.github.tartaricacid.touhoulittlemaid.datagen.tag;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitEntities;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1299;
import net.minecraft.class_2960;
import net.minecraft.class_3483;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import java.util.concurrent.CompletableFuture;

public class EntityTypeGenerator extends FabricTagProvider<class_1299<?>> {
    public static class_6862<class_1299<?>> MAID_FAIRY_ATTACK_GOAL = class_6862.method_40092(class_7924.field_41266, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "maid_fairy_attack_goal"));
    public static class_6862<class_1299<?>> MAID_VEHICLE_ROTATE_BLOCKLIST = class_6862.method_40092(class_7924.field_41266, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "maid_vehicle_rotate_blocklist"));

    public EntityTypeGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> lookupProvider) {
        super(output, class_7924.field_41266, lookupProvider);
    }

    @Override
    public void method_10514(class_7225.class_7874 lookupProvider) {
        getOrCreateTagBuilder(class_3483.field_22415).add(InitEntities.DANMAKU);
        getOrCreateTagBuilder(class_3483.field_27855).add(InitEntities.FAIRY);
        getOrCreateTagBuilder(class_3483.field_29825).add(InitEntities.FAIRY);
        getOrCreateTagBuilder(class_3483.field_42971).add(InitEntities.FAIRY);
        getOrCreateTagBuilder(class_6862.method_40092(class_7924.field_41266, id("iceandfire:immune_to_gorgon_stone"))).add(InitEntities.MAID);

        getOrCreateTagBuilder(MAID_FAIRY_ATTACK_GOAL).add(class_1299.field_6147)
                .method_35922(id("guardvillagers:guard"))
                .method_35922(id("earthtojavamobs:furnace_golem"))
                .method_35922(id("earthmobsmod:furnace_golem"))
                .method_35922(id("mutantmonsters:mutant_snow_golem"))
                .method_35922(id("alexscaves:gingerbread_man"))
                .method_35922(id("alexsmobs:bunfungus"));

        method_10512(MAID_VEHICLE_ROTATE_BLOCKLIST).method_35922(id("create:carriage_contraption"));
    }

    private class_2960 id(String name) {
        return class_2960.method_60654(name);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.4.3-neo1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/datagen/tag/EntityTypeGenerator.java <==
package com.github.tartaricacid.touhoulittlemaid.datagen.tag;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitEntities;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1299;
import net.minecraft.class_2960;
import net.minecraft.class_3483;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import java.util.concurrent.CompletableFuture;

public class EntityTypeGenerator extends FabricTagProvider<class_1299<?>> {
    public static class_6862<class_1299<?>> MAID_FAIRY_ATTACK_GOAL = class_6862.method_40092(class_7924.field_41266, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "maid_fairy_attack_goal"));
    public static class_6862<class_1299<?>> MAID_VEHICLE_ROTATE_BLOCKLIST = class_6862.method_40092(class_7924.field_41266, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "maid_vehicle_rotate_blocklist"));
    public static class_6862<class_1299<?>> CARRYON_ENTITY_BLACKLIST = class_6862.method_40092(class_7924.field_41266, class_2960.method_60655("carryon", "entity_blacklist"));

    public EntityTypeGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> lookupProvider) {
        super(output, class_7924.field_41266, lookupProvider);
    }

    @Override
    public void method_10514(class_7225.class_7874 lookupProvider) {
        getOrCreateTagBuilder(class_3483.field_22415).add(InitEntities.DANMAKU);
        getOrCreateTagBuilder(class_3483.field_27855).add(InitEntities.FAIRY);
        getOrCreateTagBuilder(class_3483.field_29825).add(InitEntities.FAIRY);
        getOrCreateTagBuilder(class_3483.field_42971).add(InitEntities.FAIRY);
        getOrCreateTagBuilder(class_6862.method_40092(class_7924.field_41266, id("iceandfire:immune_to_gorgon_stone"))).add(InitEntities.MAID);

        getOrCreateTagBuilder(MAID_FAIRY_ATTACK_GOAL).add(class_1299.field_6147)
                .method_35922(id("guardvillagers:guard"))
                .method_35922(id("earthtojavamobs:furnace_golem"))
                .method_35922(id("earthmobsmod:furnace_golem"))
                .method_35922(id("mutantmonsters:mutant_snow_golem"))
                .method_35922(id("alexscaves:gingerbread_man"))
                .method_35922(id("alexsmobs:bunfungus"));

        getOrCreateTagBuilder(MAID_VEHICLE_ROTATE_BLOCKLIST).method_35922(id("create:carriage_contraption"));
        getOrCreateTagBuilder(CARRYON_ENTITY_BLACKLIST).add(
                InitEntities.TOMBSTONE,
                InitEntities.SIT,
                InitEntities.BROOM);
    }

    private class_2960 id(String name) {
        return class_2960.method_60654(name);
    }
}
